McpServer

Struct McpServer 

pub struct McpServer { /* private fields */ }
Cloneable MCP protocol core and Actix Streamable HTTP handler.

Implementations

Source

impl McpServer

pub fn new(config: McpServerConfig) -> Result<Self, McpConfigError>

pub fn add_tool<F, Fut>(&self, tool: Tool, handler: F)
where F: Fn(RequestMetadata, Value) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Value, McpError>> + Send + 'static,

pub fn add_resource<F, Fut>(&self, resource: Resource, handler: F)
where F: Fn(RequestMetadata, Value) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Value, McpError>> + Send + 'static,

pub fn add_prompt<F, Fut>(&self, prompt: Prompt, handler: F)
where F: Fn(RequestMetadata, Value) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Value, McpError>> + Send + 'static,

pub fn configure(&self, service: &mut ServiceConfig)

Mounts the configured MCP endpoint on an Actix application.

pub fn run(&self) -> Result<Server>

Binds the configured address and starts a standalone MCP HTTP server.

pub fn run_on(&self, listener: TcpListener) -> Result<Server>

Starts a standalone MCP HTTP server on an existing listener.

pub async fn serve_until<F>(&self, shutdown: F) -> Result<()>
where F: Future<Output = ()>,

Serves until the supplied signal resolves and then gracefully drains requests.

pub async fn serve_on_until<F>( &self, listener: TcpListener, shutdown: F, ) -> Result<()>
where F: Future<Output = ()>,

Listener-based variant of McpServer::serve_until.